Rate

Struct Rate 

pub struct Rate<TQ, PQ>
where TQ: Quantity, PQ: Quantity,
{ /* private fields */ }
The ratio between two related quantity values.

Implementations

Source

impl<TQ, PQ> Rate<TQ, PQ>
where TQ: Quantity, PQ: Quantity,

pub const fn new( term_amount: Decimal, term_unit: <TQ as Quantity>::UnitType, per_unit_multiple: Decimal, per_unit: <PQ as Quantity>::UnitType, ) -> Rate<TQ, PQ>

Returns a new instance of Rate with attributes equal to given params.

pub fn from_qty_vals(term: TQ, per: PQ) -> Rate<TQ, PQ>

Returns a new instance of Rate with attributes extracted from the given quantity values.

pub const fn term_amount(&self) -> Decimal

Returns the term amount of self.

pub const fn term_unit(&self) -> <TQ as Quantity>::UnitType

Returns the term unit of self.

pub const fn per_unit_multiple(&self) -> Decimal

Returns the per unit multiple of self.

pub const fn per_unit(&self) -> <PQ as Quantity>::UnitType

Returns the per unit of self.

pub const fn reciprocal(&self) -> Rate<PQ, TQ>

Returns the multiplicative inverse of self