pub struct Rate<TQ, PQ>{ /* private fields */ }Expand description
The ratio between two related quantity values.
Implementations
Sourceimpl<TQ, PQ> Rate<TQ, PQ>
impl<TQ, PQ> Rate<TQ, PQ>
Sourcepub const fn new(
term_amount: Decimal,
term_unit: <TQ as Quantity>::UnitType,
per_unit_multiple: Decimal,
per_unit: <PQ as Quantity>::UnitType,
) -> Rate<TQ, PQ>
pub const fn new( term_amount: Decimal, term_unit: <TQ as Quantity>::UnitType, per_unit_multiple: Decimal, per_unit: <PQ as Quantity>::UnitType, ) -> Rate<TQ, PQ>
Returns a new instance of Rate with attributes equal to given params.
Sourcepub fn from_qty_vals(term: TQ, per: PQ) -> Rate<TQ, PQ>
pub fn from_qty_vals(term: TQ, per: PQ) -> Rate<TQ, PQ>
Returns a new instance of Rate with attributes extracted from the
given quantity values.
Sourcepub const fn term_amount(&self) -> Decimal
pub const fn term_amount(&self) -> Decimal
Returns the term amount of self.
Sourcepub const fn per_unit_multiple(&self) -> Decimal
pub const fn per_unit_multiple(&self) -> Decimal
Returns the per unit multiple of self.
Sourcepub const fn reciprocal(&self) -> Rate<PQ, TQ>
pub const fn reciprocal(&self) -> Rate<PQ, TQ>
Returns the multiplicative inverse of self